CursorState

Enum CursorState 

pub enum CursorState {
    None,
    Hover(usize, usize),
    Selected(usize, usize),
}
State of cursor

The 2 numbers represent the x and y in Framework.selectables rather than State.0

Variants



None

Nothing is selected



Hover(usize, usize)

Cursor is hovering on an item



Selected(usize, usize)

An item is selected

Implementations

Source

impl CursorState

pub fn is_selected(&self) -> bool

pub fn is_hover(&self) -> bool

pub fn is_none(&self) -> bool

Source

impl CursorState

pub fn select(&mut self) -> Result<(), FrameworkError>

Try select an item, will not work if an item is already selected or the cursor is not hovering on anything

pub fn deselect(&mut self) -> Result<(), FrameworkError>

Try deselect an item, will not work if no items are selected

Source

impl CursorState

pub fn to_hover(location: (usize, usize)) -> Self

pub fn to_selected(location: (usize, usize)) -> Self

pub fn hover( &self, selectables: &[Vec<(usize, usize)>], ) -> Option<(usize, usize)>

pub fn selected( &self, selectables: &[Vec<(usize, usize)>], ) -> Option<(usize, usize)>

Source

impl CursorState

pub fn move( &mut self, direction: FrameworkDirection, selectables: &[Vec<(usize, usize)>], ) -> Result<(), FrameworkError>

Move in the corresponding direction