Framework

Struct Framework 

pub struct Framework {
    pub selectables: Vec<Vec<(usize, usize)>>,
    pub data: FrameworkData,
    pub state: State,
    pub cursor: CursorState,
    pub history: Vec<FrameworkHistory>,
    pub frame_area: Option<Rect>,
}
Struct for a declarative TUI framework

Copy & paste examples can be found here

Fields

selectables: Vec<Vec<(usize, usize)>>

Selectable items, auto generated when state is set with new() or set_state()

data: FrameworkData

Global data store for the framework

state: State

Defines the layout of items on screen

cursor: CursorState

The state and position of cursor

history: Vec<FrameworkHistory>

Stores saved states

frame_area: Option<Rect>

Stores the area of the previous frame

Implementations

Source

impl Framework

pub fn clear_history(&mut self)

Clears self.history

pub fn push_history(&mut self)

Save current state

pub fn pop_history(&mut self) -> Option<FrameworkHistory>

Removes the last history and returns it

pub fn revert_last_history(&mut self) -> Result<(), FrameworkError>

Revert self to last save (if there is)

pub fn revert_history(&mut self, index: usize) -> Result<(), FrameworkError>

Revert self to history at index

Source

impl Framework

pub fn is_selected(&self) -> bool

pub fn is_hover(&self) -> bool

pub fn is_none(&self) -> bool

Source

impl Framework

pub fn new(state: State) -> Self

Create a new Framework struct

pub fn set_state(&mut self, state: State)

Set self.state and also update self.selectables

pub fn render(&mut self, frame: &mut Frame<'_>)

Render every item to screen

pub fn render_raw( &mut self, frame: &mut Frame<'_>, chunks: &[Vec<Rect>], selected: Option<(usize, usize)>, hover: Option<(usize, usize)>, popup_render: bool, )

Render to screen with more controls

pub fn render_only(&mut self, frame: &mut Frame<'_>, x: usize, y: usize)

Render only one item

pub fn render_only_multiple( &mut self, frame: &mut Frame<'_>, locations: &[(usize, usize)], )

Render multiple items

Location is in a format of Vec<(x, y)>

pub fn render_only_raw( &mut self, frame: &mut Frame<'_>, x: usize, y: usize, chunk: Rect, popup_render: bool, selected: Option<(usize, usize)>, hover: Option<(usize, usize)>, )

Render only with more controls

pub fn key_input(&mut self, key: KeyEvent) -> Result<(), Box<dyn Error>>

Send key input to selected object, returns an Err(()) when no objct is selected

pub fn mouse_event(&mut self, col: u16, row: u16) -> bool

Handles when mouse is clicked

pub fn message(&mut self, data: HashMap<String, Box<dyn Any>>) -> bool

Send message to selected object, returns true if anything updated

pub fn load(&mut self) -> Result<(), Box<dyn Error>>

pub fn load_only(&mut self, x: usize, y: usize) -> Result<(), Box<dyn Error>>

pub fn load_only_multiple(&mut self, locations: &[(usize, usize)])

Source

impl Framework

pub fn split_clean(&mut self) -> (FrameworkClean<'_>, &mut State)

Split Framework into FrameworkClean and &mut State

Source

impl Framework

pub fn move( &mut self, direction: FrameworkDirection, ) -> Result<(), FrameworkError>

Move cursor in corresponding direction, will return an Err(E) if something is selected and the cursor is not free to move around

pub fn select(&mut self) -> Result<(), Box<dyn Error>>

Select the hovering item

pub fn deselect(&mut self) -> Result<(), Box<dyn Error>>

Deselect the hovering item