pub struct State(pub Vec<Row>);Expand description
Contains the items and the layout of the TUI
Tuple Fields
0: Vec<Row>Implementations
Sourceimpl State
impl State
Sourcepub fn selectables(&self) -> Vec<Vec<(usize, usize)>>
pub fn selectables(&self) -> Vec<Vec<(usize, usize)>>
Generate selectables which is a 2D vector of items that can be selected
(usize, usize) maps to the (x, y) position to State.0, items that are not selectable
are excluded
Sourcepub fn get(&self, x: usize, y: usize) -> &dyn FrameworkItem
pub fn get(&self, x: usize, y: usize) -> &dyn FrameworkItem
Get reference to item with x and y value