pub enum CursorState {
None,
Hover(usize, usize),
Selected(usize, usize),
}Expand description
State of cursor
The 2 numbers represent the x and y in Framework.selectables rather than State.0
Variants
None
Nothing is selected
Hover(usize, usize)
Cursor is hovering on an item
Selected(usize, usize)
An item is selected
Implementations
Sourceimpl CursorState
impl CursorState
Sourceimpl CursorState
impl CursorState
Sourcepub fn select(&mut self) -> Result<(), FrameworkError>
pub fn select(&mut self) -> Result<(), FrameworkError>
Try select an item, will not work if an item is already selected or the cursor is not hovering on anything
Sourcepub fn deselect(&mut self) -> Result<(), FrameworkError>
pub fn deselect(&mut self) -> Result<(), FrameworkError>
Try deselect an item, will not work if no items are selected
Sourceimpl CursorState
impl CursorState
Sourceimpl CursorState
impl CursorState
Sourcepub fn move(
&mut self,
direction: FrameworkDirection,
selectables: &[Vec<(usize, usize)>],
) -> Result<(), FrameworkError>
pub fn move( &mut self, direction: FrameworkDirection, selectables: &[Vec<(usize, usize)>], ) -> Result<(), FrameworkError>
Move in the corresponding direction